@@ -153,7 +153,9 @@ def _download_and_unpack_bundle(bundle_type):
 
     try:
         LOGGER.info('Unpacking {} to {}'.format(bundle.name, extraction_path))
-        archive.extractall(extraction_path)
+        archive.extractall(
+            extraction_path,
+            [m for m in archive.getmembers() if m.name != ''])
     except Exception as err:
         LOGGER.error('Error when unpacking bundle: {}'.format(err))
     finally:
